bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 38. Aventiure
___________________________________________________ #### Aventivre wie des herren dietriches rechen #### alle wrden erslagen
###### 2235 | ### Do hort man allenthalben | iamer also groz ### daz palas vnd tvrne | von dem wuffe erdoz ### do hort ovch von berne | ein dieteriches man ### dvrch disiv starchen maere | wi balde er gahen began
###### 2236 | ### do sprach er zv dem fversten | hoert min her dieterich ### swaz ich noh her gelebt han | so rehte vnmvegelich ### gehort ich chlage ni mere | als ich nv han vernomen ### ich waen der chvenech ecel | ist sebe zv dem schaden chomen
###### 2237 | ### wi moehtens anders alle | haben solhen mvt ### der chvenech oder criemhilt | ir einez daz ist tot ### von den chvenen gesten | dvrh ir nit gelegen ### ez weinet vngefvge | vil manech zierlicher degen
###### 2238 | ### do sprach der helt von berne | mine vil lieben man ### nv gahet niht ce sere | swaz hi hant getan ### di ellenden recken | des gat in michel not ### vnde lat des geniezen | daz ich in minen fride enbot
###### 2239 | ### do sprach der chvene wolfhart | ich wil dar gan ### vnde wil vragen der maere | waz si hant getan ### vnd wilz iv sagen danne | vil lieber herre min ### als ich ez dort ervinde | waz div chlage mvge sin
###### 2240 | ### do sprach der herre dieterich | swa man zorns sich versiht ### ob vngefvgiv vrage | danne da geschiht ### daz betrvebet lihte den gvten | recken ir vil hohen mvt ### ia ne wil ich niht den wolfhart | daz ir di vrage gein in tvt
###### 2241 | ### do bat er helpfrichen | vil balde dar gan ### vnd hiez in daz ervinden | an eceln man ### oder an den gesten selben | waz waere da geshehen ### do ne het man von livten | so grozen iamer ni gesehen
###### 2242 | ### der bote begonde vragen | waz ist hi getan ### do sprach einer drvnder | daz ist vil gar cergan ### swaz wir vrevden heten | in der hivnen lant ### hi lit erslagen rvedeger | von der bvrgonden hant
###### 2243 | ### di mit im dar in chomen | der ist einer niht genesen ### do ne chonde helpfriche | nimmer leider wesen ### ia ne gesaget er maere | so rehte vngerne nie ### der bote zv dieteriche | vil sere weinende gie
###### 2244 | ### waz habt ir vns erfvnden | sprach do dieterich ### wi weinet ir so sere | degen helpfrich ### do sprach der edele recke | ich mag wol balde chlagen ### den gvten rvedgeren | hant die bvrgonde erslagen
###### 2245 | ### do sprach der helt von berne | daz en sol niht wellen got ### daz waere ein starchiv rache | vnde ovch des tivels spot ### wamit het rvedger | an in daz versolt ### ia ist mir daz wol chvende | er ist den ellenden holt
###### 2246 | ### des antwurte wolfhart | vnde heten siz getan ### so solt ez in allen | an ir lebn gan ### ob wirz in vertrvegen | des waere wir geschant ### ia hat vns vil gedienet | des gvten rvedgeres hant
###### 2247 | ### der vogt der amelvnge | hiez ez ervinden baz ### vil harte snellechlice | er in ein venster saz ### do bat er hildebranden | zv den gesten gan ### daz er an in erfvende | waz da waere getan
###### 2248 | ### der stvrmchvene reche | meister hildbrant ### weder schilt noch waffen | trvg er an der hant ### er wolde in sinen zvehten | zv den gesten gan ### von swesterchinde | wart im ein straffen getan
###### 2249 | ### do sprach der grimme wolfhart | welt ir dar blozer gan ### so mag er an ein schelten | nimmer wol gestan ### so mvezet ir lasterlichen | tvn di widervart ### chvmt ir dar gewaffent | daz etelicher wol bewart
###### 2250 | ### do garte sich der wise | dvrch des tvmben rat ### e daz ers innen wurde | do waren in ir wat ### alle dieteriches recken | vnt trvgen swert enhant ### dem helde was leide | vil gerne het erz erwant
###### 2251 | ### er vragte war si wolden | wir wellen mit iv dar ### waz ob von tronege hagene | deste wirs gevar ### gein iv mit spotte sprechen | des er wol chan pflegen ### do er daz gehorte | davon gestattes in der degen
###### 2252 | ### do sach der chvene wolker | wol gewaffent gan ### di recken von berne | di dieteriches man ### begvertet mit den swerten | si trvgen schilt enhant ### er sagetez sinem herren | vzer bvergonden lant
###### 2253 | ### do sprach der videlaere | ich sihe dort her gan ### so rehte vientliche | di dieteriches man ### gewaffent vnder helme | si wellent vns bestan ### ich waen ez an daz vebele | welle vns ellenden gan
###### 2254 | ### in den selben ziten | chom ovch hildebrant ### da satzet er fver di fveze | sines schildes rant ### er begonde vragen | di gvntheres man ### owe ir gvten helde | waz het iv rvedger getan
###### 2255 | ### mich hat min herre dieterich | her zv ziv gesant ### ob erslagen hete | iwer deheines hant ### den edeln margraven | als vns daz ist geseit ### wirn chvnden veberwinden | niht div grozlichen leit
###### 2256 | ### do sprach von tronege hagene | daz maere ist vngelogen ### wi wol ich iv des gvnde | het iv der bote betrogen ### dvrch rvedegeres liebe | daz noch lebte sin lip ### den immer mvgen weinen | beide man vnd ovch div wip
###### 2257 | ### do si daz rehte erhorten | daz er waere tot ### do chlageten in di recken | ir triwe in daz gebot ### den dieteriches recken | sach man traehne gan ### veber berte vnde vber chinne | in was vil leide getan
###### 2258 | ### der herzoge von berne | ce sigestap do sprach ### nv hat gar ein ende | genomen der gemach ### den vns ie gefvgete rvdeger | nach vnser leide tagen ### vroevde ellender diete | lit an rvedger erslagen
###### 2259 | ### do sprach von amelvngen | der degen wolfin ### vnd ob ich hivte saehe | tot den vater min ### mir en wurde nimmer leider | danne vmbe sinen lip ### owe wer sol nv troesten | des edeln margraven wip
###### 2260 | ### do sprach in zornes mvote | der degen wolfhart ### wer wiset nv di recken | so manege herewart ### also der margrave | vil diche hat getan ### owe vil edel rvedeger | daz wir dich svs verlorn han
###### 2261 | ### wolfprant vnd helpfrich | vnd ovch helmnot ### mit allen ir vrivnden | chlagten sinen tot ### vor svften mohte vragen | niht mere hildebrant ### er sprach nv tvt ir degene | darnach min herre hat gesant
###### 2262 | ### gebt vns rvedgern | also toten vz dem sal ### an dem gar mit iamer | lit vnser vrevdenval ### lat vns an im dienen | daz er ie hat began ### an vns vil groze triwe | vnd an manegem andern man
###### 2263 | ### wir sin ovch ellende | als rvedger der degen ### wes lazet ir uns pitet | lat in vns after waegen ### tragen daz wir nach tode | lonen noch dem man ### wir hetenz pilliche | bi sime lebene getan
###### 2264 | ### do sprach der kvenech gventher | ni dienest wart so gvt ### so den ein vrivnt vrivnde | nach dem tode tvt ### daz heiz ich staete triwe | der di chan began ### ir lonet im nach schvlden | er hat iv liebes vil getan
###### 2265 | ### wi lange svln wir vlegen | sprach wolfhart der degen ### sit vnser trost der beste | von iv ist tot gelegen ### vnd wir sin leider mere | mvegen niht gehaben ### lat en vns hinnen tragen | daz wir den recken begraben
###### 2266 | ### des antwurte volker | niemen in iv git ### nemt en in dem hvse | da der degen lit ### mit starch verchwunden | gevallen in daz plvt ### so ist ez ein voller dienest | den ir rvedgeren tvt
###### 2267 | ### do sprach der chvene wolfhart | got weiz her spilman ### ir en dverffet vns niht reizen | ir habt vns leit getan ### getorst ich vor minem herren | so choemet irs in not ### des mvezen wirz lazen | wand er vns striten hi verbot
###### 2268 | ### do sprach der videlaere | der vorhte ist gar ce vil ### swaz man im verbivtet | derz allez wil ### daz chan ich niht geheizen | rehten heldes mvt ### div rede duhte hagenen | uon sinem hergesellen gvt
###### 2269 | ### des en lat iuch niht belangen | sprach aber wolfhart ### ich entrihte iv so di seiten | swenne ir di wideruart ### ritet gein dem rine | daz irz uuol muget sagen ### iuuer vebermueten | mag ich mit eren niht vertragen
###### 2270 | ### do sprach der uidelaere | swenne ir di seiten min ### verirret guter doene | der iuuer helme schin ### der muz uil truebe uuerden | von der minen hant ### suui halt ich gerite | in der buergonden lant
###### 2271 | ### do uuold er zv zim springen | wande daz in niht en lie ### hildebrant sin oheim | in uaste zim gevie ### ich waene du woldest toben | durch den tumben zorn ### mines herren hulde | hetes du immer mer verlorn
###### 2272 | ### lat abe den lewen meister | er ist so grimme gemut ### chumt aber er mir cen handen | sprach volker der degen gut ### het er di uuerlt alle | mit siner hant erslagen ### ich slahe in daz erz uuiderspel | nimmer mer darf gesagen
###### 2273 | ### des wart uil harte erzvernet | der bernaere mut ### den schilt gezvchte wolfhart | ein sneller degen gut ### alsam ein lev wilder | lief er uor in dan ### im wart ein gahez volgen | uon sinen vriunden getan
###### 2274 | ### swi witer sprunge er pflaege | fuer des sales want ### doch ergahte in vor der stiege | der alte hildebrant ### er en wolde in uor im lazen | niht chomen in den strit ### si funden daz si suchten | an den ellenden sit
###### 2275 | ### do gespranch zv hagenen | meister hildebrant ### diu swert man horte erchlingen | an ir beider hant ### si waren ser erzvernet | daz mohte man chiesen sint ### von ir zweier swerten | gie fiwerroter wint
###### 2276 | ### di wurden do gescheiden | in des sturmes not ### daz taten di uon berne | als in ir chrapft gebot ### zehant do wande hildebrant | uon hagenen wider dan ### do lief der starche wolfhart | den chvenen volkeren an
###### 2277 | ### er sluch den uidelaere | vf den helm gut ### daz des swertes ecke | vnz an di spangen wut ### daz vergalt mit ellen | der chuene spilman ### do slug er wolfharten | daz er stieben began
###### 2278 | ### des fiwers vz den ringen | hiwen si genuch ### haz ir iegelicher | dem andern da truch ### di shiet do von berne | der degen wolfin ### ob ez ein helt niht waere | des en chunde niht gesin
###### 2279 | ### guenther der recke | mit uil willeger hant ### enpfie di helde maere | von amelunge lant ### giselher der herre | diu liehten helmvaz ### der frumt er da uil manigez | uon pluote rot unde naz
###### 2280 | ### danchwart hagen bruder | was ein grimmech man ### swaz er da uor hete | in strite ie getan ### den eceln recken | daz was gar ein wint ### nu naht uil tobeliche | des chuenen aldrianes chint
###### 2281 | ### ritschart unde gerbart | helpfrich unde wichart ### di heten in manegn sturmen | uil selten sich gespart ### des brahten si wol innen | di guentheres man ### do sach man wolpranden | in strite herliche gan
###### 2282 | ### do uaht alsam er wuote vder alte hildebrant ### uil der guten recken | uor wolfhartes hant ### mit tode musen uallen | uon swerten in daz pluot ### sus rachen ruedgeren | di recken chuene unde gut
###### 2283 | ### do uaht der herre sigestap | als im sin ellen riet ### hey waz er in dem strite | guter helme uerschriet ### den sinen uianden | dieteriches swester sun ### er en chunde in dem sturme | nimmer bezzers niht getun
###### 2284 | ### uolker der starche | do er daz ersach ### daz sigestap der chuene | den bluotegen bach ### hiu uzzer herten ringen | daz was dem helde zorn ### er spranch im hin engegene | do het sigestap uerlorn
###### 2285 | ### von dem uidelaere | uil schiere da daz sin leben ### er begonde im siner chvenste | alsolhen teil da geben ### daz er uon sinem swerte | muose ligen tot ### daz rach der alte hildebrant | als im sin ellen daz gebot
###### 2286 | ### owe liebes herren | sprach meister hildebrant ### der hi lit erstorben | uon volkeres hant ### nu sol der uidelaere | langer niht genesen ### hildebrant der chuene | wi chund er grimmer gewesen
###### 2287 | ### do sluch er volkeren | daz im div helmbant ### stuben allenthalben | zu des sals want ### uon helm vnd ouch uon schilde | dem chuenen spileman ### dauon der starche volker | do den ende da gewan
###### 2288 | ### do drungen zu dem strite | di dieteriches man ### unt daz man ort der swert | uil hohe uliegen sach ### si holten uz den helmen | den hieze uliezenden bach
###### 2289 | ### do sach uon tronege hagene | volkeren tot ### daz was cer hohgezite | sin allermeistiv not ### di er da hete gewunnen | an magen und ouch an man ### owe wi harte hagene | den helt do rechen began
###### 2290 | ### nu ne sol es niht geniezen | der alte hildebrant ### min helfe lit erslagen | uon des heldes hant ### der beste hergeselle | den ich ie gewan ### den schilt er ruchte hoher | do gi er howende dan
###### 2291 | ### helpfrich der chuene | danchwarten sluch ### guenthere unde giselhere | den was ez leit genuch ### do si in uallen sahen | in der starchen not ### er hete mit sinen handen | uil wol uergolten sinen tot
###### 2292 | ### di wile gie do wolfhart | beide wider unde dan ### allez howende | di guentheres man ### er was di driten chere | chomen durch den sal ### da uiel uon sinen handen | uil manech recke ce tal
###### 2293 | ### do rief der herre giselher | wolfharten an ### owe daz ich so grimmen | uient ie gewan ### edel ritter chuene | nu wendet gegen in ### ich wilz helfen enden | ez en mag niht lenger gesin
###### 2294 | ### zv giselhere cherte | wolfrhat in den strit ### do sluch ietwederr | uil manege wunden wit ### so rehte krepftechlichen | er zv dem kvenege dranch ### daz imez pluot under fuezen | al ueber daz houbet spranch
###### 2295 | ### mit swinden slegen grimme | der schonen vten chint ### enpfie er wolfharten | den chvenen helt sint ### swi starch der degen waere | ern chunde niht genesen ### ez en dorfte kvenech so iunger | nimmer chuener gewesen
###### 2296 | ### do sluch er wolfharten | durch eine brvenne gvt ### daz im uon der wunden | nider uloz daz pluot ### er wunte zu dem tode | den dieteriches man ### ez en het an einen recken | zware niemen getan
###### 2297 | ### also der chuene wolfhart | der wunden do enpfant ### den schilt den liez er uallen | hoher an der hant ### hub er ein starchez waffen | daz was starch genuch ### durch helm unt durch ringe | der helt do giselheren sluch
###### 2298 | ### si heten beide einander | den grimmen tot getan ### do ne lebte ouch niht mere bder dieteriches man ### hildebrant der alte | wolfharten uallen sach ### im waene vor sinem tode | so rehte leide ni geschach
###### 2299 | ### do waren gar erstorben | di guentheres man ### vnd ouch di dieteriches | hildebrant was gegan ### da wolfhart was gevallen | nider in daz plut ### er besloz mit armen | den recken chven vnde gut
###### 2300 | ### er wolden uzem huse | mit im tragen dan ### er was ein teil ce swaere | er muse in ligen lan ### do blichte ouch vz dem bluote | der rewende man ### er sach wol daz im gerne | sin neve het geholffen dan
###### 2301 | ### do sprach der totwunde | vil lieber oheim min ### ir muegt an disen ziten | mir niht frvm gesin ### nv hvetet iuch vor hagenen | ia dunchet ez mich gut ### er treit in sinem hercen | einen grimmigen mvt
###### 2302 | ### vnde ob mich mine mage | nach tode wellen chlagen ### den naehestn vnt den besten | den sult ir von mir sagen ### daz si nach mir niht weinen | daz ist ane not ### uor eines kveneges handen | lige ich hi herlichen tot
###### 2303 | ### ich han ouch so vergolten | hirinne minen lip ### daz ez wol mvgen beweinen | der guten ritter wip ### ob iuch des iemen vrage | so muegt ir balde sagen ### vor min eines handen | ligent wol hundert erslagen
###### 2304 | ### do gedaht ovch hagen | an den spileman ### dem der chvne hildebrant | sin leben an gewan ### do sprach er zv dem degene | ir geltet miniv leit ### ir habt vns hinne enbunden | vil maneges recken gemeit
###### 2305 | ### er sluch vf hildebranden | daz man wol vernam ### balmvngen diezen | den sifride nam ### hagen der chvene | da er den helt ersluch ### do werte sich der alte | ia was er chvene genuch
###### 2306 | ### der recke dieteriches | sluch ein waffen breit ### vf den helt von tronege | daz ovch vil sere sneit ### do ne chunder niht verwunden | den guentheres man ### do sluoch aber in hagene | durch eine brvenne wolgetan
###### 2307 | ### do der alte hildebrant | der wunden enpfant ### do uorhte er schaden mere | von der hagenen hant ### den schilt warf veber ruke | der dieteriches man ### mit der starchen wunden | der helt do hagenen entran
###### 2308 | ### da was niemen lebende | aller der degene ### niwan di einen zwene | guenther vnd hagene ### mit bluote gie bervnnen | der alte hildebrant ### er brahte leidiv maere | da er dieterichen vant
###### 2309 | ### do sah er trvrechliche | sitzen hi den man ### der leide michel mere | der fverste do gewan ### er sah ouch hildebranden | in siner brvenne rot ### do vragete er der maere | als im div sorge gebot
###### 2310 | ### nv sagt mir meister hildebrant | wi sit ir so naz ### von dem verchpluote | oder wer tet iv daz ### ich waene ir mit den gesten | zem huse habt gestriten ### ich verbot ez iv so sere | ir hetez pilliche vermiten
###### 2311 | ### do sagt er sinem herren | ez tet hagene ### der slug mir dise wunden | in dem gademe ### do ich von dem recken | wolde wenden dan ### mit dem minem lebene | ich dem tivfel vil chvme entran
###### 2312 | ### do sprach der bernaere | vil rehte ist iv geschehen ### do ir mich frivntschepfte | den recken hortet gehen ### daz ir den vride brachet | den ich in hete gegeben ### het ich es niht immer shande | ir soldet vliesen daz leben
###### 2313 | ### nv zvernet niht so sere | min her dieterich ### an mir vnd minen frivnden | der schade ist al ce rich ### wir wolden rvedgeren | getragen haben dan ### des en wolden vns niht gunnen | des chvnech gventheres man
###### 2314 | ### so we mir dirre leide | ist ruedeger doch tot ### daz mvz mir sin ein iamer | vor aller miner not ### goetelint div edele | ist miner pasen chint ### ach we der armen weisen | di da ce bechlaren sint
###### 2315 | ### triwen vnde leides | mant mich sin tot ### er begonde starche weinen | des gie dem helde not ### owe getriwer helde | di ich verlon han ### ia ne veberwinde ich nimmer | des chvenech eceln man
###### 2316 | ### mveget ir mir meister hildebrant | div maere rehte sagen ### wer der recke waere | der in da habe erslagen ### er sprach daz tet mit chrepften | der starche gernot ### vor ruedgeres henden | ist ovch der helt gelegen tot
###### 2317 | ### er sprach ce hildebrande | nv sagt minen man ### daz si sich palde waffen | wand ich wil dar gan ### vnde heizet mir gewinnen | min liehtez wichgewant ### ich wil selbe vragen | di helde vzer burgonden lant
###### 2318 | ### do sprach meister hildebrant | wer sol zv ziv gen ### swaz ir habt der lebenden | di seht ir hi bi iv sten ### daz pin ich alterseine | di andern di sint tot ### do erschract er dirre maere | des gie im waerliche not
###### 2319 | ### wand er leit so grozez | cer werld nie gewan ### er sprach vnde sint erstorben | alle mine man ### so hat min got vergezzen | ich armer dieterich ### ich was ein chvnech here | vil gewaltech vnd rich
###### 2320 | ### wi chvnde ez sich gefvegen | sprah her dieterich ### daz si alle sint erstorben | di helde lobelich ### von den stritmueden | di doch heten not ### wande durch min vngeluecke | in waere vremde noch der tot
###### 2321 | ### sit daz es min vnschulde | niht langer wolde entwesen ### so sagt mir ist den geste | noch iemen genesen ### do sprach meister hildebrant | daz weiz got niemen mer ### niwan hagen aleine | vnde guenther der kvenech her
###### 2322 | ### owe lieber wolfhart | sol ich dich han verlorn ### so mag mich balde riwen | daz ich ie wart geborn ### sygestap vnd wolfwin | vnd ouch wolfprant ### wer sol mir danne helffen | in der amelunge lant
###### 2323 | ### helpfrich der vil chvene | vnd ist mir der erslagen ### gerbart vnd wichart | wi solde ich di uerchlagen ### daz ist an minen vrevden | mir der leste tach ### owe daz vor leide | niemen sterbene mach

<<< Übersicht <<< vorige Seite nächste Seite >>>